@@ -1,11 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "universal-sidecar-roam" "1.9.0"
+(define-package "universal-sidecar-roam" "20251029.1934"
   "Integrate universal-sidecar and org-roam."
   '((emacs             "26.1")
     (universal-sidecar "1.0.0")
     (org-roam          "2.0.0"))
   :url "https://git.sr.ht/~swflint/emacs-universal-sidecar"
   :commit "01b12aecca0ce66f5427e7fe65012d37e7e128b2"
-  :revdesc "v1.9.0-0-g01b12aecca0c"
+  :revdesc "01b12aecca0c"
   :authors '(("Samuel W. Flint" . "me@samuelwflint.com"))
   :maintainers '(("Samuel W. Flint" . "me@samuelwflint.com")))
